<template>
  <!-- 备品件添加 -->
  <div>
    <el-dialog :close-on-click-modal="false" :title="title + '领用申请单'" :visible.sync="showFormDia" width="60%"
      :before-close="handleClose" custom-class="bbsl-location-dialog" top="8vh">
      <div class="bbsl-scroll-pane">
        <el-form ref="formInfo" class="bbsl-scroll-form-spare" :rules="rules" :model="params" label-width="120px">
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>基本信息</span>
          </p>
          <el-row>
            <el-col :span="12">
              <el-form-item label="申请标题：" prop="applyTitle">
                <el-input :readonly="statusInput" v-model="params.applyTitle" placeholder="请输入申请标题" />
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="申请日期：" prop="applicationDate">
                <el-date-picker :readonly="statusInput" v-model="params.applicationDate" type="date"
                  value-format="yyyy-MM-dd" placeholder="请选择申请日期" style="width:100%" />
              </el-form-item>
            </el-col>
            <el-col :span="24">
                <el-form-item label="申请部门：" prop="applicationDept">
                  <el-radio-group v-model="params.applicationDept" style="width: 100%;">
                    <el-radio v-for="item in orgOptions" :key="item.id" :label="item.id">{{ item.name }}</el-radio>
                  </el-radio-group>
                </el-form-item>
              </el-col>
          </el-row>
          <el-form-item label="领用事由">
            <el-input :readonly="statusInput" v-model="params.applicationCase" type="textarea" maxlength="500"
              show-word-limit :autosize="{ minRows: 3, maxRows: 4 }" placeholder="请输入事由内容" />
          </el-form-item>
          <p id="step2" class="from-title">
            <i class="el-icon-info" />
            <span>领用物资明细</span>
          </p>
          <el-table :data="purchasingDetailList" style="width: 100%" :height="260" highlight-current-row
            @row-click="tableCurrentChange" @header-click="tableHeaderClick">
            <!-- <el-table-column label="序号" prop="sn" width="60" /> -->
            <el-table-column label="序号" width="70">
              <template slot-scope="scope">
                {{ scope.$index + 1 }}
              </template>
            </el-table-column>
            <el-table-column :key="k" label="品名" min-width="100" prop="name">
            </el-table-column>
            <el-table-column label="规格型号" min-width="120" prop="model">
            </el-table-column>
            <el-table-column label="单位" width="80" prop="unit" />
            <el-table-column label="参考单价(元)" width="100" prop="price" />
            <el-table-column label="库存" width="100" prop="remainingQuantity" />
            <el-table-column label="领用数量" prop="quantity">
              <template slot-scope="scope">
                <el-input v-model.number="scope.row.quantity" @input="
                    if (scope.row.quantity > scope.row.remainingQuantity)
                  scope.row.quantity = scope.row.remainingQuantity
                    " size="mini" />
              </template>
            </el-table-column>
            <el-table-column v-if="statusInput == false" align="right" width="90px" :index="999">
              <template slot="header">
                <el-button size="mini" circle type="primary" icon="el-icon-plus" @click="selectMaterial" />
              </template>
              <template slot-scope="scope">
                <el-button size="mini" type="danger" circle icon="el-icon-close"
                  @click="deleteDetail(scope.$index, scope.row)" />
              </template>
            </el-table-column>
          </el-table>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button v-if="statusInput == false" type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>

    <SelectMaterialDialog ref="materialDia" @saveSelectMaterial="saveMaterial"
      :purchasingDetailList="purchasingDetailList" :pageName="pageName" />
  </div>
</template>
<script>
import { mapState } from "vuex";
import CommonApi from '@/views/Manage/CommonApi.js'
import purchasingManage from '@/api/manager/material/purchasingManage.js'
import purchasingApi from '../api/PurchasingApi'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import SelectMaterialDialog from '@/views/Manage/material/components/SelectMaterialDialog.vue'
export default {
  name: 'PurchasingManageDialog',
  components: {
    SelectMaterialDialog
  },
  props: {},
  data() {
    return {
      statusInput: false,
      pageName: '领用申请',
      userSelectOptions: [],
      currnetRow: null,
      k: 0,
      title: '新增',
      showFormDia: false,
      showMaterialDia: false,
      isEdit: false,
      activeName: 'PurchasingDetail',
      purchasingDetailList: [],
      params: {
        applicationCase: '',
        applicationDate: '',
        applicationDept: '',
        applicationDeptName:'',
        applyTitle: '',
        approver: '',
        approvedDate: '',
        id: null,
        memo: '',
        pkVal: '',
        detailList: [],
        sn: 0,
        applyType: '2',
        version: 0
        // description: '',
        // id: '',
        // isDele: '',
        // lastTime: '',
        // materialId: '',
        // model: '',
        // name: '',
        // pkVal: '',
        // sn: 0,
        // unit: ''
      },
      rules: {
        applyTitle: [
          {
            required: true,
            message: '请输入申请标题',
            trigger: 'blur'
          }
        ],
        applicationDept: [
          {
            required: true,
            message: '请输入申请部门',
            trigger: 'blur'
          }
        ],
        applicant: [
          {
            required: true,
            message: '请输入申请人',
            trigger: 'blur'
          }
        ],
        applicationCase: [
          {
            required: true,
            message: '请输入申请事由',
            trigger: 'blur'
          }
        ],
        quantity: [
          {
            required: true,
            message: '请输入领用数量',
            trigger: 'blur'
          }
        ],
        applicationDate: [
          {
            required: true,
            message: '请选择申请时间',
            trigger: 'blur'
          }
        ]
      },
      orgOptions: []
    }
  },
  computed: mapState({
    currentUserDetail: state => state.user.currentUserDetail
  }),
  created() {
    purchasingApi.getUserAllOrg(res => {
      this.orgOptions = res.org
    })
    CommonApi.loadSelectOptions(
      {
        name: 'manageCommonService.getAllUsers',
        query: '96240625-934F-490B-8AA6-0BC775B18468'
      },
      res => {
        // console.log('=========userSelectOptions=====', res)
        this.userSelectOptions = res
      }
    )
  },
  methods: {
    //领用人
    userChange(v, s) {
      const vobj = this.userSelectOptions.find(u => {
        return u.id === v
      })
      if (vobj) {
        this.params.applicantName = vobj.fullname
        // this.params.orgId = vobj.orgId
      }
    },
    // //新增申请采购明细列表
    // requestPurchaseList() {
    //   purchasingApi.findByOrgUseDetail().then(res => {
    //     // console.log(res)
    //     // this.total = res.total
    //     this.purchasingDetailList = res.value
    //     // this.$set(this.tableData)
    //     // this.loading = false
    //   })
    // },
    //编辑申请采购明细列表
    detailListFun() {
      purchasingApi.getDetailListDetail(this.params.id).then(res => {
        // console.log(res)
        this.purchasingDetailList = res.value
      })
    },
    add() {
      const userinfo = this.$store.state.user.currentUserDetail
      if (!userinfo || !userinfo.org[0]) {
        this.$message.error('当前登录用户没有所属组织，请联系管理员')
      } else {
        this.params.applicationDept = userinfo.org[0].orgId
        this.params.applicationDeptName = userinfo.org[0].orgName
        // this.params.applicant = userinfo.user.fullname
        var date = new Date()
        this.params.applicationDate = date.format('yyyy-MM-dd')
        this.showFormDia = true
        // this.requestPurchaseList()
      }

    },
    handleClose() {
      this.params = {
        applicationCase: '',
        applicationDate: '',
        applicationDept: '',
        applicationDeptName: '',
        applyTitle: '',
        approver: '',
        approvedDate: '',
        id: null,
        memo: '',
        pkVal: '',
        detailList: [],
        sn: 0,
        applyType: '2',
        version: 0
      }
      this.$refs.formInfo.clearValidate()
      this.purchasingDetailList = []
      this.title = '新增'
      this.showFormDia = false
      this.statusInput = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method = 'sdfs'
          if (this.title == '新增') {
            // 新增
            method = purchasingApi.purchasingAdd
          }
          if (this.title == '修改') {
            // 修改
            method = purchasingApi.purchasingUpdate
          }
          this.params.detailList = this.purchasingDetailList
          // console.log(this.params)

          let bool = this.purchasingDetailList.every(function (item) {
            return item.quantity !== undefined && item.quantity !== '' //判断条件
          })
          const findObj = this.orgOptions.find(item => item.id === this.params.applicationDept)
          this.params.applicationDeptName = findObj.name
          if (bool == false) {
            this.$message.error('领用数量不能为空')
          } else {
            method(this.params, res => {
              console.log(res)
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: this.title + '成功',
                  duration: 2000
                })
                // this.$emit('loadData')
                this.$parent.loadData()
                console.log(22222222)
                this.handleClose()
              } else {
                this.$message.warning(response.message)
              }
            })
          }
        }
      })
    },
    Update(row, detail) {
      console.log(row, detail)
      this.title = '修改'
      this.showFormDia = true
      // this.params.memo = row.memo
      this.params.applyTitle = row.applyTitle
      // this.params.applicant = row.applicant
      this.params.applicationDate = row.applicationDate
      this.params.applicationDept = row.applicationDept
      this.params.applicationDeptName = row.applicationDeptName
      this.params.applicationCase = row.applicationCase
      this.params.id = row.id
      if (row.status == '2') {
        this.statusInput = true
      }
      // this.purchasingDetailList = detail
      this.detailListFun()
      this.$parent.loadData()
    },
    addRow() {
      //
      var row = {
        quantity: 0,
        name: '',
        model: '',
        memo: '',
        id: null,
        purchasingId: null,
        materialInfoId: null
      }
      this.purchasingDetailList.push(row)
    },
    deleteDetail(index, row) {
      this.purchasingDetailList.splice(index, 1)
    },
    selectMaterial() {
      this.$refs.materialDia.showDia = true
      this.$refs.materialDia.selectionEcho()
    },
    saveMaterial(arr) {
      this.purchasingDetailList = []
      console.log(arr)
      arr.forEach(m => {
        this.purchasingDetailList.push(m)
      })
      this.$refs.materialDia.showDia = false
      this.$refs.materialDia.materialSelection = []
    },
    tableCurrentChange(row) {
      if (this.currnetRow) {
        this.currnetRow.isEdit = false
      }
      row.isEdit = true
      this.currnetRow = row
      this.k++
    },
    tableHeaderClick(col) {
      if (!(col.index && col.index === 999)) {
        this.purchasingDetailList.forEach(item => {
          item.isEdit = false
        })
        this.currnetRow = null
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.redBull {
  border: 1px solid red;
}

.bbsl-scroll-form-spare {
  width: calc(100% - 20px);
  // height: calc(95vh - 320px);
  overflow-y: auto;
  padding: 0 10px;
}
</style>
